local g = vim.g
local opt = vim.opt

g.mapleader = ' '
g.tex_flavor = 'latex'
g.c_syntax_for_h = true
vim.cmd([[
let g:VM_default_mappings 	    = 0
let g:VM_mouse_mappings             = 1
let g:VM_leader                     = {'default': ',', 'visual': ',', 'buffer': ','}
let g:VM_maps                       = {}
let g:VM_maps['i']                  = 'l'
let g:VM_maps['I']                  = 'L'
let g:VM_maps['Find Under']         = '<c-h>'
let g:VM_maps["Add Cursor At Pos"]  = ',,'
let g:VM_maps['Find Subword Under'] = '<c-h>'
let g:VM_maps["Add Cursor Down"]    = '<C-n>'
let g:VM_maps["Add Cursor Up"]      = '<C-e>'
let g:VM_maps['Find Next']          = 'k'
let g:VM_maps['Find Prev']          = 'K'
let g:VM_custom_motions             = {'n': 'j', 'j': 'n', 'l': 'i', 'e': 'k', 'i': 'l'}
function! NvimGdbNoTKeymaps()
  tnoremap <silent> <buffer> <esc> <c-\><c-n>
endfunction

let g:nvimgdb_config_override = {
  \ 'key_next': 'k',
  \ 'key_step': 's',
  \ 'key_finish': 'f',
  \ 'key_continue': 'c',
  \ 'key_until': 'u',
  \ 'key_breakpoint': 'b',
  \ 'set_tkeymaps': "NvimGdbNoTKeymaps",
  \ }
]])

opt.termguicolors = true
opt.mouse = 'nv'
opt.fileencoding = 'utf-8'
opt.splitbelow = true
opt.splitright = true
opt.showmode = false
opt.undofile = true
opt.updatetime = 300
opt.backup = false
opt.clipboard:prepend { 'unnamedplus', 'unnamed' }
opt.ignorecase = true
opt.smartcase = true
opt.sessionoptions = 'folds'
opt.foldlevelstart = 1
opt.number = true
opt.shortmess:append('I', 'W', 's')
opt.iskeyword:prepend { '-' }
opt.timeoutlen = 300
opt.fillchars = 'eob: '
opt.cmdheight = 1
opt.grepprg = 'rg --vimgrep --no-heading --smart-case --hidden'
opt.grepformat = '%f:%l:%c:%m'

vim.api.nvim_create_user_command('Cd', 'lcd %:p:h', { nargs = 0 })
vim.api.nvim_create_user_command('Grep', 'silent grep! <args> | TroubleToggle quickfix', { nargs = '+' })

local ignore_buftype = { 'quickfix', 'nofile', 'help' }
local ignore_filetype = { 'gitcommit', 'gitrebase', 'svn', 'hgcommit' }

local function run()
	if vim.tbl_contains(ignore_buftype, vim.bo.buftype) then
		return
	end

	if vim.tbl_contains(ignore_filetype, vim.bo.filetype) then
		-- reset cursor to first line
		vim.cmd [[normal! gg]]
		return
	end

	-- If a line has already been specified on the command line, we are done
	--   nvim file +num
	if vim.fn.line '.' > 1 then
		vim.cmd [[normal! zz]]
		return
	end

	local last_line = vim.fn.line [['"]]
	local buff_last_line = vim.fn.line '$'

	-- If the last line is set and the less than the last line in the buffer
	if last_line > 0 and last_line <= buff_last_line then
		local win_last_line = vim.fn.line 'w$'
		local win_first_line = vim.fn.line 'w0'
		-- Check if the last line of the buffer is the same as the win
		if win_last_line == buff_last_line then
			-- Set line to last line edited
			vim.cmd [[normal! g`"]]
			-- Try to center
		elseif buff_last_line - last_line > ((win_last_line - win_first_line) / 2) - 1 then
			vim.cmd [[normal! g`"zz]]
		else
			vim.cmd [[normal! G'"<c-e>]]
		end
	end
end

vim.api.nvim_create_autocmd({ 'BufWinEnter', 'FileType' }, {
	group = vim.api.nvim_create_augroup('nvim-lastplace', {}),
	callback = run,
})
